@@ -1,6 +1,6 @@
 import pickle
 
-from django_dynamodb_cache.encode.base import BaseEncode
+from enkonix_django_dynamodb_cache.encode.base import BaseEncode
 
 
 class PickleEncode(BaseEncode):
